@@ -7,7 +7,7 @@
  | permitted exceptions and without any warranty. For full license    |
  | and copyright information, see https://civicrm.org/licensing       |
  +--------------------------------------------------------------------+
-*/
+ */
 
 /**
  *
@@ -16,10 +16,10 @@
  *
  */
 
-
-// This file must not accessed directly
-if ( ! defined( 'ABSPATH' ) ) exit;
-
+// This file must not accessed directly.
+if (!defined('ABSPATH')) {
+  exit;
+}
 
 /**
  * Define CiviCRM_For_WordPress_Users Class.
@@ -29,31 +29,28 @@ if ( ! defined( 'ABSPATH' ) ) exit;
 class CiviCRM_For_WordPress_Users {
 
   /**
+   * @var object
    * Plugin object reference.
-   *
    * @since 4.6
    * @access public
-   * @var object $civi The plugin object reference.
    */
   public $civi;
 
-
   /**
    * Instance constructor.
    *
    * @since 4.6
    */
-  function __construct() {
+  public function __construct() {
 
-    // Store reference to CiviCRM plugin object
+    // Store reference to CiviCRM plugin object.
     $this->civi = civi_wp();
 
-    // Always listen for activation action
-    add_action( 'civicrm_activation', array( $this, 'activate' ) );
+    // Always listen for activation action.
+    add_action('civicrm_activation', [$this, 'activate']);
 
   }
 
-
   /**
    * Plugin activation tasks.
    *
@@ -61,12 +58,14 @@ class CiviCRM_For_WordPress_Users {
    */
   public function activate() {
 
-    // Assign minimum capabilities for all WP roles and create 'anonymous_user' role
+    /*
+     * Assign minimum capabilities for all WordPress roles and create
+     * 'anonymous_user' role.
+     */
     $this->set_wp_user_capabilities();
 
   }
 
-
   /**
    * Register hooks.
    *
@@ -74,22 +73,23 @@ class CiviCRM_For_WordPress_Users {
    */
   public function register_hooks() {
 
-    // Add CiviCRM access capabilities to WordPress roles
+    // Add CiviCRM access capabilities to WordPress roles.
     $this->set_access_capabilities();
 
-    // Do not hook into user updates if CiviCRM not installed yet
-    if ( ! CIVICRM_INSTALLED ) return;
+    // Do not hook into user updates if CiviCRM not installed yet.
+    if (!CIVICRM_INSTALLED) {
+      return;
+    }
 
-    // Synchronise users on insert and update
-    add_action( 'user_register', array( $this, 'update_user' ) );
-    add_action( 'profile_update', array( $this, 'update_user' ) );
+    // Synchronise users on insert and update.
+    add_action('user_register', [$this, 'update_user']);
+    add_action('profile_update', [$this, 'update_user']);
 
-    // Delete ufMatch record when a WordPress user is deleted
-    add_action( 'deleted_user', array( $this, 'delete_user_ufmatch' ), 10, 1 );
+    // Delete ufMatch record when a WordPress user is deleted.
+    add_action('deleted_user', [$this, 'delete_user_ufmatch'], 10, 1);
 
   }
 
-
   /**
    * Check permissions.
    *
@@ -100,23 +100,23 @@ class CiviCRM_For_WordPress_Users {
    * @param array $args The page arguments array.
    * @return bool True if authenticated, false otherwise.
    */
-  public function check_permission( $args ) {
+  public function check_permission($args) {
 
-    if ( $args[0] != 'civicrm' ) {
+    if ($args[0] != 'civicrm') {
       return FALSE;
     }
 
     $config = CRM_Core_Config::singleton();
 
-    // Set frontend true
+    // Set frontend true.
     $config->userFrameworkFrontend = TRUE;
 
     require_once 'CRM/Utils/Array.php';
 
-    // All profile and file urls, as well as user dashboard and tell-a-friend are valid
+    // All profile and file urls, as well as user dashboard and tell-a-friend are valid.
     $arg1 = CRM_Utils_Array::value(1, $args);
-    $invalidPaths = array('admin');
-    if ( in_array( $arg1, $invalidPaths ) ) {
+    $invalidPaths = ['admin'];
+    if (in_array($arg1, $invalidPaths)) {
       return FALSE;
     }
 
@@ -124,7 +124,6 @@ class CiviCRM_For_WordPress_Users {
 
   }
 
-
   /**
    * Get "permission denied" text.
    *
@@ -135,33 +134,31 @@ class CiviCRM_For_WordPress_Users {
    * @return string Warning message.
    */
   public function get_permission_denied() {
-    return __( 'You do not have permission to access this content.', 'civicrm' );
+    return __('You do not have permission to access this content.', 'civicrm');
   }
 
-
   /**
    * Handle WordPress user events.
    *
-   * Callback function for 'user_register' hook
-   * Callback function for 'profile_update' hook
+   * Callback function for 'user_register' hook.
+   * Callback function for 'profile_update' hook.
    *
-   * CMW: seems to (wrongly) create new CiviCRM Contact every time a user changes their
-   * first_name or last_name attributes in WordPress.
+   * CMW: seems to (wrongly) create new CiviCRM Contact every time a user changes
+   * their first_name or last_name attributes in WordPress.
    *
    * @since 4.6
    *
-   * @param int $user_id The numeric ID of the WordPress user
+   * @param int $user_id The numeric ID of the WordPress user.
    */
-  public function update_user( $user_id ) {
+  public function update_user($user_id) {
 
-    $user = get_userdata( $user_id );
-    if ( $user ) {
-      $this->sync_user( $user );
+    $user = get_userdata($user_id);
+    if ($user) {
+      $this->sync_user($user);
     }
 
   }
 
-
   /**
    * Keep WordPress user synced with CiviCRM Contact.
    *
@@ -169,10 +166,10 @@ class CiviCRM_For_WordPress_Users {
    *
    * @param object $user The WordPress user object.
    */
-  public function sync_user( $user = FALSE ) {
+  public function sync_user($user = FALSE) {
 
     // Sanity check
-    if ( $user === FALSE OR !is_a($user, 'WP_User') ) {
+    if ($user === FALSE || !is_a($user, 'WP_User')) {
       return;
     }
 
@@ -187,52 +184,39 @@ class CiviCRM_For_WordPress_Users {
      * to the CiviCRM Contact, we have to search for it all over again.
      */
     CRM_Core_BAO_UFMatch::synchronize(
-      $user, // User object
-      TRUE, // Update = true
-      'WordPress', // CMS
-      'Individual' // contact type
+      // User object.
+      $user,
+      // Update = true.
+      TRUE,
+      // CMS.
+      'WordPress',
+      // Contact Type.
+      'Individual'
     );
 
-    /*
-    // IN PROGRESS: synchronizeUFMatch does return the contact object, however
-    $civi_contact = CRM_Core_BAO_UFMatch::synchronizeUFMatch(
-      $user, // User object
-      $user->ID, // ID
-      $user->user_mail, // Unique identifier
-      null // Unused
-      'WordPress' // CMS
-      'Individual' // contact type
-    );
-
-    // Now we can allow other plugins to do their thing
-    do_action( 'civicrm_contact_synced', $user, $civi_contact );
-    */
-
   }
 
-
   /**
-   * When a WordPress user is deleted, delete the ufMatch record.
+   * When a WordPress user is deleted, delete the UFMatch record.
    *
-   * Callback function for 'delete_user' hook
+   * Callback function for 'delete_user' hook.
    *
    * @since 4.6
    *
    * @param $user_id The numerical ID of the WordPress user.
    */
-  public function delete_user_ufmatch( $user_id ) {
+  public function delete_user_ufmatch($user_id) {
 
     if (!$this->civi->initialize()) {
       return;
     }
 
-    // Delete the ufMatch record
+    // Delete the UFMatch record.
     require_once 'CRM/Core/BAO/UFMatch.php';
     CRM_Core_BAO_UFMatch::deleteUser($user_id);
 
   }
 
-
   /**
    * Create anonymous role and define capabilities.
    *
@@ -248,12 +232,12 @@ class CiviCRM_For_WordPress_Users {
   public function set_wp_user_capabilities() {
 
     global $wp_roles;
-    if ( ! isset( $wp_roles ) ) {
+    if (!isset($wp_roles)) {
       $wp_roles = new WP_Roles();
     }
 
-    // Minimum capabilities (Civicrm permissions) arrays
-    $default_min_capabilities =  array(
+    // Define minimum capabilities (CiviCRM permissions).
+    $default_min_capabilities = [
       'access_civimail_subscribe_unsubscribe_pages' => 1,
       'access_all_custom_data' => 1,
       'access_uploaded_files' => 1,
@@ -265,7 +249,7 @@ class CiviCRM_For_WordPress_Users {
       'view_event_info' => 1,
       'sign_civicrm_petition' => 1,
       'view_public_civimail_content' => 1,
-    );
+    ];
 
     /**
      * Allow minimum capabilities to be filtered.
@@ -275,28 +259,27 @@ class CiviCRM_For_WordPress_Users {
      * @param array $default_min_capabilities The minimum capabilities.
      * @return array $default_min_capabilities The modified capabilities.
      */
-    $min_capabilities = apply_filters( 'civicrm_min_capabilities', $default_min_capabilities );
+    $min_capabilities = apply_filters('civicrm_min_capabilities', $default_min_capabilities);
 
-    // Assign the Minimum capabilities (Civicrm permissions) to all WP roles
-    foreach ( $wp_roles->role_names as $role => $name ) {
-      $roleObj = $wp_roles->get_role( $role );
-      foreach ( $min_capabilities as $capability_name => $capability_value ) {
-        $roleObj->add_cap( $capability_name );
+    // Assign the minimum capabilities to all WordPress roles.
+    foreach ($wp_roles->role_names as $role => $name) {
+      $roleObj = $wp_roles->get_role($role);
+      foreach ($min_capabilities as $capability_name => $capability_value) {
+        $roleObj->add_cap($capability_name);
       }
     }
 
     // Add the 'anonymous_user' role with minimum capabilities.
-    if ( ! in_array( 'anonymous_user' , $wp_roles->roles ) ) {
+    if (!in_array('anonymous_user', $wp_roles->roles)) {
       add_role(
         'anonymous_user',
-        __( 'Anonymous User', 'civicrm' ),
+        __('Anonymous User', 'civicrm'),
         $min_capabilities
       );
     }
 
   }
 
-
   /**
    * Add CiviCRM access capabilities to WordPress roles.
    *
@@ -311,7 +294,7 @@ class CiviCRM_For_WordPress_Users {
 
     // Test for existing global
     global $wp_roles;
-    if ( ! isset( $wp_roles ) ) {
+    if (!isset($wp_roles)) {
       $wp_roles = new WP_Roles();
     }
 
@@ -326,43 +309,46 @@ class CiviCRM_For_WordPress_Users {
      * @param array The default roles with access to CiviCRM.
      * @return array The modified roles with access to CiviCRM.
      */
-    $roles = apply_filters( 'civicrm_access_roles', array( 'super admin', 'administrator' ) );
+    $roles = apply_filters('civicrm_access_roles', ['super admin', 'administrator']);
 
-     // Give access to CiviCRM to particular roles.
-    foreach ( $roles as $role ) {
-      $roleObj = $wp_roles->get_role( $role );
+    // Give access to CiviCRM to particular roles.
+    foreach ($roles as $role) {
+      $roleObj = $wp_roles->get_role($role);
       if (
-        is_object( $roleObj ) &&
-        is_array( $roleObj->capabilities ) &&
-        ! array_key_exists( 'access_civicrm', $wp_roles->get_role( $role )->capabilities )
+        is_object($roleObj) &&
+        is_array($roleObj->capabilities) &&
+        !array_key_exists('access_civicrm', $wp_roles->get_role($role)->capabilities)
       ) {
-        $wp_roles->add_cap( $role, 'access_civicrm' );
+        $wp_roles->add_cap($role, 'access_civicrm');
       }
     }
 
   }
 
-
   /**
-   * Get CiviCRM contact type.
+   * Get CiviCRM Contact Type.
    *
    * @since 4.6
    *
-   * @param string $default The requested contact type.
-   * @return string $ctype The computed contact type.
+   * @param string $default The requested Contact Type.
+   * @return string $ctype The computed Contact Type.
    */
-  public function get_civicrm_contact_type( $default = NULL ) {
+  public function get_civicrm_contact_type($default = NULL) {
 
-    // Here we are creating a new contact
-    // Get the contact type from the POST variables if any
-    if ( isset( $_REQUEST['ctype'] ) ) {
+    /*
+     * Here we are creating a new Contact.
+     * Get the Contact Type from the POST variables if any.
+     */
+    if (isset($_REQUEST['ctype'])) {
       $ctype = $_REQUEST['ctype'];
-    } elseif (
-      isset( $_REQUEST['edit'] ) &&
-      isset( $_REQUEST['edit']['ctype'] )
+    }
+    elseif (
+      isset($_REQUEST['edit']) &&
+      isset($_REQUEST['edit']['ctype'])
     ) {
       $ctype = $_REQUEST['edit']['ctype'];
-    } else {
+    }
+    else {
       $ctype = $default;
     }
 
@@ -378,7 +364,4 @@ class CiviCRM_For_WordPress_Users {
 
   }
 
-
-} // Class CiviCRM_For_WordPress_Users ends
-
-
+}
